==> SuiteCRM-8.8.0.zip: core/backend/Migrations/Version20250115144124.php <==
<?php
/**
 * SuiteCRM is a customer relationship management program developed by SalesAgility Ltd.
 * Copyright (C) 2025 SalesAgility Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SALESAGILITY, SALESAGILITY DISCLAIMS THE
 * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Supercharged by SuiteCRM" logo. If the display of the logos is not reasonably
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Supercharged by SuiteCRM".
 */

declare(strict_types=1);

namespace App\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Symfony\Component\DependencyInjection\ContainerAwareInterface;
use Symfony\Component\Filesystem\Filesystem;

final class Version20250115144124 extends BaseMigration implements ContainerAwareInterface
{
    public function getDescription(): string
    {
        return 'Add logs/legacy folder';
    }

    public function up(Schema $schema): void
    {
        $filesystem = new Filesystem();
        try {
            if (!$filesystem->exists('logs/legacy')) {
                $filesystem->mkdir('logs/legacy');
                $this->log('Added logs/legacy');
            } else {
                $this->log('logs/legacy already exists');
            }
        } catch (\Exception $e) {
            $this->log('Failed to ad dlogs/legacy. Error: ' . $e->getMessage());
        }
    }

    public function down(Schema $schema): void
    {
    }
}

==> SuiteCRM-8.9.1.zip: core/backend/Migrations/Version20250115144124.php <==
<?php
/**
 * SuiteCRM is a customer relationship management program developed by SuiteCRM Ltd.
 * Copyright (C) 2025 SuiteCRM Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUITECRM, SUITECRM DISCLAIMS THE
 * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Supercharged by SuiteCRM" logo. If the display of the logos is not reasonably
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Supercharged by SuiteCRM".
 */

declare(strict_types=1);

namespace App\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Symfony\Component\DependencyInjection\ContainerAwareInterface;
use Symfony\Component\Filesystem\Filesystem;

final class Version20250115144124 extends BaseMigration implements ContainerAwareInterface
{
    public function getDescription(): string
    {
        return 'Add logs/legacy folder';
    }

    public function up(Schema $schema): void
    {
        $filesystem = new Filesystem();
        try {
            if (!$filesystem->exists('logs/legacy')) {
                $filesystem->mkdir('logs/legacy');
                $this->log('Added logs/legacy');
            } else {
                $this->log('logs/legacy already exists');
            }
        } catch (\Exception $e) {
            $this->log('Failed to add logs/legacy. Error: ' . $e->getMessage());
        }
    }

    public function down(Schema $schema): void
    {
    }
}
